/// Quantity types and constants with universal application.
///
library universal;

import 'package:quantity/quantity.dart';

export 'package:quantity/quantity.dart'
    show
        characteristicImpedanceOfVacuum,
        speedOfLightVacuum,
        magneticConstant,
        planckConstant,
        hBar,
        planckLength,
        planckMass,
        planckTemperature,
        planckTime,
        electricConstant,
        Length,
        Mass,
        Speed,
        Permeability,
        Permittivity,
        Resistance,
        Temperature,
        Time,
        MiscQuantity,
        AngularMomentum,
        WaveNumber;

const Speed c = speedOfLightVacuum;
const Speed c0 = c;

Permeability mu0 = magneticConstant;

Permittivity eps0 = electricConstant;

Resistance Z0 = characteristicImpedanceOfVacuum;

const MiscQuantity newtonianConstantOfGravitation = const MiscQuantity.constant(
    const Double.constant(6.67408e-11), const Dimensions.constant(const {"Length": 3, "Mass": -1, "Time": -2}),
    uncert: 4.64483494354278e-5);

const MiscQuantity G = newtonianConstantOfGravitation;

const AngularMomentum h = planckConstant;

const WaveNumber rydberg =
    const WaveNumber.constant(const Double.constant(10973731.568508), uncert: 5.92323582859768e-12);
